@@ -3,19 +3,19 @@
  *****************************************************************************
  * Copyright © 2011-2012 VLC authors and VideoLAN
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
  *****************************************************************************/
 
 #include <stdio.h>
@@ -51,7 +51,7 @@ int aout_open(void **opaque, char *format, unsigned *rate, unsigned *nb_channels
 
     aout_sys_t *p_sys = calloc (1, sizeof (*p_sys));
     if (!p_sys)
-        return -1;
+        goto enomem;
 
     p_sys->j_libVlc = *opaque;       // Keep a reference to our Java object
     *opaque         = (void*) p_sys; // The callback will need aout_sys_t
@@ -63,7 +63,7 @@ int aout_open(void **opaque, char *format, unsigned *rate, unsigned *nb_channels
     if ((*myVm)->AttachCurrentThread (myVm, &p_env, NULL) != 0)
     {
         LOGE("Could not attach the display thread to the JVM !");
-        return -1;
+        goto eattach;
     }
 
     // Call the init function.
@@ -121,8 +121,10 @@ int aout_open(void **opaque, char *format, unsigned *rate, unsigned *nb_channels
 
 error:
     (*myVm)->DetachCurrentThread (myVm);
+eattach:
     *opaque = NULL;
     free (p_sys);
+enomem:
     return -1;
 }
 
