@@ -1,7 +1,7 @@
 /*****************************************************************************
  * libvlcjni.c
  *****************************************************************************
- * Copyright © 2010-2012 VLC authors and VideoLAN
+ * Copyright © 2010-2013 VLC authors and VideoLAN
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -180,22 +180,14 @@ static libvlc_media_player_t *getMediaPlayer(JNIEnv *env, jobject thiz)
     return (libvlc_media_player_t*)(intptr_t)getLong(env, thiz, "mInternalMediaPlayerInstance");
 }
 
-static libvlc_media_list_player_t *getMediaListPlayer(JNIEnv *env, jobject thiz)
-{
-    return (libvlc_media_list_player_t*)(intptr_t)getLong(env, thiz, "mMediaListPlayerInstance");
-}
-
 static void releaseMediaPlayer(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t* p_mlp = getMediaListPlayer(env, thiz);
-    if (p_mlp)
+    libvlc_media_player_t* p_mp = getMediaPlayer(env, thiz);
+    if (p_mp)
     {
-        libvlc_media_list_player_stop(p_mlp);
-        libvlc_media_list_player_release(p_mlp);
-        /* libvlc_media_list_player_release frees the media player, so
-         * we don't free it ourselves. */
+        libvlc_media_player_stop(p_mp);
+        libvlc_media_player_release(p_mp);
         setLong(env, thiz, "mInternalMediaPlayerInstance", 0);
-        setLong(env, thiz, "mMediaListPlayerInstance", 0);
     }
 }
 
@@ -211,12 +203,18 @@ static jobject debugBufferInstance = NULL;
 static pthread_mutex_t vout_android_lock;
 static void *vout_android_surf = NULL;
 static void *vout_android_gui = NULL;
+static jobject vout_android_java_surf = NULL;
 
 void *jni_LockAndGetAndroidSurface() {
     pthread_mutex_lock(&vout_android_lock);
     return vout_android_surf;
 }
 
+jobject jni_LockAndGetAndroidJavaSurface() {
+    pthread_mutex_lock(&vout_android_lock);
+    return vout_android_java_surf;
+}
+
 void jni_UnlockAndroidSurface() {
     pthread_mutex_unlock(&vout_android_lock);
 }
@@ -354,6 +352,7 @@ void Java_org_videolan_libvlc_LibVLC_attachSurface(JNIEnv *env, jobject thiz, jo
     (*env)->DeleteLocalRef(env, clz);
 
     vout_android_gui = (*env)->NewGlobalRef(env, gui);
+    vout_android_java_surf = (*env)->NewGlobalRef(env, surf);
     pthread_mutex_unlock(&vout_android_lock);
 }
 
@@ -362,7 +361,10 @@ void Java_org_videolan_libvlc_LibVLC_detachSurface(JNIEnv *env, jobject thiz) {
     vout_android_surf = NULL;
     if (vout_android_gui != NULL)
         (*env)->DeleteGlobalRef(env, vout_android_gui);
+    if (vout_android_java_surf != NULL)
+        (*env)->DeleteGlobalRef(env, vout_android_java_surf);
     vout_android_gui = NULL;
+    vout_android_java_surf = NULL;
     pthread_mutex_unlock(&vout_android_lock);
 }
 
@@ -515,6 +517,10 @@ void Java_org_videolan_libvlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz)
         "--no-stats",
         "--no-plugins-cache",
         "--no-drop-late-frames",
+        /* The VLC default is to pick the highest resolution possible
+         * (i.e. 1080p). For mobile, pick a more sane default for slow
+         * mobile data networks and slower hardware. */
+        "--preferred-resolution", "360",
         "--avcodec-fast",
         "--avcodec-threads=0",
         "--subsdec-encoding", subsencodingstr,
@@ -673,7 +679,6 @@ static void create_player_and_play(JNIEnv* env, jobject thiz,
     libvlc_media_list_t* p_mlist = getMediaList(env, thiz);
 
     /* Create a media player playing environment */
-    libvlc_media_list_player_t* p_mlp = libvlc_media_list_player_new((libvlc_instance_t*)(intptr_t)instance);
     libvlc_media_player_t *mp = libvlc_media_player_new((libvlc_instance_t*)(intptr_t)instance);
 
     jobject myJavaLibVLC = (*env)->NewGlobalRef(env, thiz);
@@ -702,14 +707,49 @@ static void create_player_and_play(JNIEnv* env, jobject thiz,
     for(int i = 0; i < (sizeof(mp_events) / sizeof(*mp_events)); i++)
         libvlc_event_attach(ev, mp_events[i], vlc_event_callback, myVm);
 
-    libvlc_media_list_player_set_media_list(p_mlp, p_mlist);
-    libvlc_media_list_player_set_media_player(p_mlp, mp);
 
     /* Keep a pointer to this media player */
-    setLong(env, thiz, "mMediaListPlayerInstance", (jlong)(intptr_t)p_mlp);
     setLong(env, thiz, "mInternalMediaPlayerInstance", (jlong)(intptr_t)mp);
 
-    libvlc_media_list_player_play_item_at_index(p_mlp, position);
+    setInt(env, thiz, "mInternalMediaPlayerIndex", (jint)position);
+    libvlc_media_list_lock(p_mlist);
+    libvlc_media_t* p_md = libvlc_media_list_item_at_index(p_mlist, position);
+    libvlc_media_list_unlock(p_mlist);
+    libvlc_media_player_set_media(mp, p_md);
+    libvlc_media_player_play(mp);
+}
+
+jint Java_org_videolan_libvlc_LibVLC_expandMedia(JNIEnv *env, jobject thiz)
+{
+    int current_position = getInt(env, thiz, "mInternalMediaPlayerIndex");
+    libvlc_media_list_t* p_mlist = getMediaList(env, thiz);
+    libvlc_media_list_lock(p_mlist);
+    libvlc_media_t* p_md = libvlc_media_list_item_at_index(p_mlist, current_position);
+    libvlc_media_list_unlock(p_mlist);
+    libvlc_media_list_t* p_subitems = libvlc_media_subitems(p_md);
+    libvlc_media_release(p_md);
+    if(p_subitems) {
+        // Expand any subitems if needed
+        int subitem_count = libvlc_media_list_count(p_subitems);
+        if(subitem_count > 0) {
+            LOGD("Found %d subitems, expanding", subitem_count);
+            libvlc_media_list_lock(p_mlist);
+            for(int i = subitem_count - 1; i >= 0; i--) {
+                libvlc_media_list_insert_media(p_mlist, libvlc_media_list_item_at_index(p_subitems, i), current_position+1);
+            }
+            libvlc_media_list_remove_index(p_mlist, current_position);
+            libvlc_media_list_unlock(p_mlist);
+        }
+        libvlc_media_list_release(p_subitems);
+        if(subitem_count > 0) {
+            create_player_and_play(env, thiz,
+                getLong(env, thiz, "mLibVlcInstance"), current_position);
+            return (jint)current_position;
+        } else
+            return -1;
+    } else {
+        return -1;
+    }
 }
 
 jint Java_org_videolan_libvlc_LibVLC_readMedia(JNIEnv *env, jobject thiz,
@@ -766,6 +806,10 @@ void Java_org_videolan_libvlc_LibVLC_getMediaListItems(
     libvlc_media_list_unlock( p_mlist );
 }
 
+void Java_org_videolan_libvlc_LibVLC_removeIndex(JNIEnv *env, jobject thiz, jlong instance, jint position) {
+    libvlc_media_list_remove_index((libvlc_media_list_t*)(intptr_t)instance, position);
+}
+
 jfloat Java_org_videolan_libvlc_LibVLC_getRate(JNIEnv *env, jobject thiz) {
     libvlc_media_player_t* mp = getMediaPlayer(env, thiz);
     if(mp)
@@ -994,14 +1038,14 @@ end:
 
 jboolean Java_org_videolan_libvlc_LibVLC_hasMediaPlayer(JNIEnv *env, jobject thiz)
 {
-    return !!getMediaListPlayer(env, thiz);
+    return !!getMediaPlayer(env, thiz);
 }
 
 jboolean Java_org_videolan_libvlc_LibVLC_isPlaying(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
+    libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
-        return !!libvlc_media_list_player_is_playing(mp);
+        return !!libvlc_media_player_is_playing(mp);
     else
         return 0;
 }
@@ -1016,37 +1060,46 @@ jboolean Java_org_videolan_libvlc_LibVLC_isSeekable(JNIEnv *env, jobject thiz)
 
 void Java_org_videolan_libvlc_LibVLC_play(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
+    libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
-        libvlc_media_list_player_play(mp);
+        libvlc_media_player_play(mp);
 }
 
 void Java_org_videolan_libvlc_LibVLC_pause(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
+    libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
-        libvlc_media_list_player_pause(mp);
+        libvlc_media_player_pause(mp);
 }
 
 void Java_org_videolan_libvlc_LibVLC_stop(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
+    libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
-        libvlc_media_list_player_stop(mp);
+        libvlc_media_player_stop(mp);
 }
 
 void Java_org_videolan_libvlc_LibVLC_previous(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
-    if (mp)
-        libvlc_media_list_player_previous(mp);
+    int current_position = getInt(env, thiz, "mInternalMediaPlayerIndex");
+
+    if(current_position-1 >= 0) {
+        setInt(env, thiz, "mInternalMediaPlayerIndex", (jint)(current_position-1));
+        create_player_and_play(env, thiz,
+             getLong(env, thiz, "mLibVlcInstance"), current_position-1);
+    }
 }
 
 void Java_org_videolan_libvlc_LibVLC_next(JNIEnv *env, jobject thiz)
 {
-    libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
-    if (mp)
-        libvlc_media_list_player_next(mp);
+    libvlc_media_list_t* p_mlist = getMediaList(env, thiz);
+    int current_position = getInt(env, thiz, "mInternalMediaPlayerIndex");
+
+    if(current_position+1 < libvlc_media_list_count(p_mlist)) {
+        setInt(env, thiz, "mInternalMediaPlayerIndex", (jint)(current_position+1));
+        create_player_and_play(env, thiz,
+             getLong(env, thiz, "mLibVlcInstance"), current_position+1);
+    }
 }
 
 jint Java_org_videolan_libvlc_LibVLC_getVolume(JNIEnv *env, jobject thiz)
