@@ -1,7 +1,7 @@
 /*****************************************************************************
  * LibVLC.java
  *****************************************************************************
- * Copyright © 2010-2012 VLC authors and VideoLAN
+ * Copyright © 2010-2013 VLC authors and VideoLAN
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -38,8 +38,8 @@ public class LibVLC {
 
     /** libVLC instance C pointer */
     private long mLibVlcInstance = 0; // Read-only, reserved for JNI
-    /** libvlc_media_list_player pointer */
-    private long mMediaListPlayerInstance = 0; // Read-only, reserved for JNI
+    /** libvlc_media_player pointer and index */
+    private int mInternalMediaPlayerIndex = 0; // Read-only, reserved for JNI
     private long mInternalMediaPlayerInstance = 0; // Read-only, reserved for JNI
     /** libvlc_media_list_t pointer */
     private long mMediaListInstance = 0; // Read-only, reserved for JNI
@@ -397,6 +397,12 @@ public class LibVLC {
         return mIsBufferingLog;
     }
 
+    /** Media list functions **/
+    public void removeIndex(int position) {
+        removeIndex(mMediaListInstance, position);
+    }
+    private native void removeIndex(long media_list_instance, int position);
+
     /**
      * Read a media
      * @param instance: the instance of libVLC
@@ -566,6 +572,15 @@ public class LibVLC {
      */
     public native void getMediaListItems(ArrayList<String> arl);
 
+     /**
+      * A function to flatten the playlist. This function checks the
+      * currently playing media. If there are any subitems, it will
+      * expand them and replace the current media.
+      *
+      * @return the index of the media was expanded, and -1 if no media was expanded
+      */
+    public native int expandMedia();
+
     /**
      * Return the length of the stream, in milliseconds
      */
