@@ -28,6 +28,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Locale;
 import java.util.Stack;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -346,7 +347,7 @@ public class MediaLibrary {
                 if (mRestart) {
                     Log.d(TAG, "Restarting scan");
                     mRestart = false;
-                    restartHandler.sendEmptyMessage(1);
+                    restartHandler.sendEmptyMessageDelayed(1, 200);
                 } else {
                     mRestartContext = null;
                     mContext = null;
@@ -355,20 +356,23 @@ public class MediaLibrary {
         }
     };
 
-    private Handler restartHandler = new Handler() {
-        @Override
-        public void handleMessage(final Message msgs) {
-            restartHandler.postDelayed(new Runnable() {
-                @Override
-                public void run() {
-                    if (mRestartContext != null)
-                        loadMediaItems(mRestartContext);
-                    else
-                        Log.e(TAG, "Context lost in a black hole");
-                }
-            }, 200);
+    private Handler restartHandler = new RestartHandler(this);
+
+    private static class RestartHandler extends WeakHandler<MediaLibrary> {
+        public RestartHandler(MediaLibrary owner) {
+            super(owner);
         }
-    };
+
+        @Override
+        public void handleMessage(Message msg) {
+            MediaLibrary owner = getOwner();
+            if(owner == null) return;
+            if (owner.mRestartContext != null)
+                owner.loadMediaItems(owner.mRestartContext);
+            else
+                Log.e(TAG, "Context lost in a black hole");
+        }
+    }
 
     /**
      * Filters all irrelevant files
@@ -379,10 +383,10 @@ public class MediaLibrary {
         public boolean accept(File f) {
             boolean accepted = false;
             if (!f.isHidden()) {
-                if (f.isDirectory() && !Media.FOLDER_BLACKLIST.contains(f.getPath().toLowerCase())) {
+                if (f.isDirectory() && !Media.FOLDER_BLACKLIST.contains(f.getPath().toLowerCase(Locale.ENGLISH))) {
                     accepted = true;
                 } else {
-                    String fileName = f.getName().toLowerCase();
+                    String fileName = f.getName().toLowerCase(Locale.ENGLISH);
                     int dotIndex = fileName.lastIndexOf(".");
                     if (dotIndex != -1) {
                         String fileExt = fileName.substring(dotIndex);
