@@ -50,18 +50,27 @@ public class VlcCrashHandler implements UncaughtExceptionHandler {
 
         final Writer result = new StringWriter();
         final PrintWriter printWriter = new PrintWriter(result);
+
+        // Inject some info about android version and the device, since google can't provide them in the developer console
+        StackTraceElement[] trace = ex.getStackTrace();
+        StackTraceElement[] trace2 = new StackTraceElement[trace.length+3];
+        System.arraycopy(trace, 0, trace2, 0, trace.length);
+        trace2[trace.length+0] = new StackTraceElement("Android", "MODEL", android.os.Build.MODEL, -1);
+        trace2[trace.length+1] = new StackTraceElement("Android", "VERSION", android.os.Build.VERSION.RELEASE, -1);
+        trace2[trace.length+2] = new StackTraceElement("Android", "FINGERPRINT", android.os.Build.FINGERPRINT, -1);
+        ex.setStackTrace(trace2);
+
         ex.printStackTrace(printWriter);
         String stacktrace = result.toString();
         printWriter.close();
-
         Log.e(TAG, stacktrace);
-        if(!Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED)) {
-            defaultUEH.uncaughtException(thread, ex);
-            return; // We can't save the log if SD card is unavailable
+
+        // Save the log on SD card if available
+        if(Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED)) {
+            String sdcardPath = Environment.getExternalStorageDirectory().getPath();
+            writeLog(stacktrace, sdcardPath + "/vlc_crash");
+            writeLogcat(sdcardPath + "/vlc_logcat");
         }
-        String sdcardPath = Environment.getExternalStorageDirectory().getPath();
-        writeLog(stacktrace, sdcardPath + "/vlc_crash");
-        writeLogcat(sdcardPath + "/vlc_logcat");
 
         defaultUEH.uncaughtException(thread, ex);
     }
