@@ -34,6 +34,7 @@ import org.videolan.vlc.Util;
 import org.videolan.vlc.VLCApplication;
 
 import android.content.Context;
+import android.os.Build;
 import android.os.Environment;
 import android.util.Log;
 import android.view.LayoutInflater;
@@ -413,7 +414,8 @@ public class DirectoryAdapter extends BaseAdapter {
         ArrayList<String> a = new ArrayList<String>();
         // i = 1 to exclude ".." folder
         for(int i = 1; i < mCurrentNode.children.size(); i++)
-            a.add(getMediaLocation(i));
+            if(mCurrentNode.children.get(i).isFile)
+                a.add(getMediaLocation(i));
         return a;
     }
 
@@ -437,7 +439,7 @@ public class DirectoryAdapter extends BaseAdapter {
     }
 
     private String getVisibleName(File file) {
-        if (android.os.Build.VERSION.SDK_INT >= 17) {
+        if (android.os.Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
             // Show "sdcard" for the user's folder when running in multi-user
             if (file.getAbsolutePath().equals(Environment.getExternalStorageDirectory().getPath())) {
                 return VLCApplication.getAppContext().getString(R.string.internal_memory);
