@@ -49,6 +49,7 @@ import android.content.Intent;
 import android.content.IntentFilter;
 import android.content.SharedPreferences;
 import android.content.res.Configuration;
+import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
 import android.os.Message;
@@ -230,7 +231,7 @@ public class VideoGridFragment extends SherlockGridFragment implements ISortable
             gv.setColumnWidth(Util.convertDpToPx(GRID_ITEM_WIDTH_DP));
             mVideoAdapter.setListMode(false);
         } else {
-            Log.e(TAG, "Switching to list mode");
+            Log.d(TAG, "Switching to list mode");
             gv.setNumColumns(1);
             gv.setStretchMode(LIST_STRETCH_MODE);
             gv.setHorizontalSpacing(LIST_HORIZONTAL_SPACING_DP);
@@ -315,7 +316,7 @@ public class VideoGridFragment extends SherlockGridFragment implements ISortable
         return super.onContextItemSelected(menu);
     }
 
-    @TargetApi(11)
+    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
     public void onContextPopupMenu(View anchor, final int position) {
         if (!Util.isHoneycombOrLater()) {
             // Call the "classic" context menu
